summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xbootstrap/installer-docker.sh-template4
-rw-r--r--healthcheck-container/healthcheck.js5
-rw-r--r--healthcheck-container/package.json2
-rw-r--r--healthcheck-container/pom.xml2
-rwxr-xr-xk8s-bootstrap-container/bootstrap.sh3
-rwxr-xr-xk8s-bootstrap-container/load-blueprints.sh3
-rw-r--r--k8s-bootstrap-container/pom.xml2
-rw-r--r--pnda-bootstrap-container/Dockerfile9
-rw-r--r--pnda-mirror-container/Dockerfile5
9 files changed, 21 insertions, 14 deletions
diff --git a/bootstrap/installer-docker.sh-template b/bootstrap/installer-docker.sh-template
index 4f889fc..1364dc1 100755
--- a/bootstrap/installer-docker.sh-template
+++ b/bootstrap/installer-docker.sh-template
@@ -383,7 +383,7 @@ curl -X PUT -H "Content-Type: application/json" --data-binary '[{"username":"doc
# Install platform Docker host
# Note we're still in the "consul" directory, which is init'ed for talking to CM
-set +e
+set +e
# Docker host for platform containers
cfy install -v -p ./blueprints/docker/${DOCKERBP} -b DockerBP -d DockerPlatform -i ../${INPUTS} -i "registered_dockerhost_name=platform_dockerhost" -i "registrator_image=onapdcae/registrator:v7" -i "location_id=${LOCATION}" -i "node_name=dokp00" -i "target_datacenter=${LOCATION}"
@@ -451,7 +451,7 @@ cfy install -p ./blueprints/hrules/${HRULESBP} -b hrules -d hrules -i ../config/
cfy install -p ./blueprints/hengine/${HENGINEBP} -b hengine -d hengine -i ../config/he-ip.yaml
# PRH
-cfy install -p ./blueprints/prh/${PRHBP} -b prh -d prh -i ../config/prhinput.yaml
+cfy install -p ./blueprints/prh/${PRHBP} -b prh -d prh -i ../config/prh-input.yaml
# HV-VES
cfy install -p ./blueprints/hv-ves/${HVVESBP} -b hv-ves -d hv-ves
diff --git a/healthcheck-container/healthcheck.js b/healthcheck-container/healthcheck.js
index ca1df84..159de1f 100644
--- a/healthcheck-container/healthcheck.js
+++ b/healthcheck-container/healthcheck.js
@@ -39,7 +39,10 @@ const dcaeDeps =
'dep-service-change-handler',
'dep-policy-handler',
'dep-dcae-ves-collector',
- 'dep-dcae-tca-analytics'
+ 'dep-dcae-tca-analytics',
+ 'dep-dcae-prh',
+ 'dep-dcae-hv-ves-collector',
+ 'dep-dcae-datafile-collector'
];
const status = require('./get-status');
diff --git a/healthcheck-container/package.json b/healthcheck-container/package.json
index c4b7560..cce714b 100644
--- a/healthcheck-container/package.json
+++ b/healthcheck-container/package.json
@@ -1,7 +1,7 @@
{
"name": "k8s-healthcheck",
"description": "DCAE healthcheck server",
- "version": "1.1.0",
+ "version": "1.1.2",
"main": "healthcheck.js",
"dependencies": {
"request": "2.85.0"
diff --git a/healthcheck-container/pom.xml b/healthcheck-container/pom.xml
index 415c1cb..43a2535 100644
--- a/healthcheck-container/pom.xml
+++ b/healthcheck-container/pom.xml
@@ -27,7 +27,7 @@ limitations under the License.
<groupId>org.onap.dcaegen2.deployments</groupId>
<artifactId>healthcheck-container</artifactId>
<name>dcaegen2-deployments-healthcheck-container</name>
- <version>1.1.0</version>
+ <version>1.1.2</version>
<url>http://maven.apache.org</url>
<properties>
<project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
diff --git a/k8s-bootstrap-container/load-blueprints.sh b/k8s-bootstrap-container/load-blueprints.sh
index 4bc8004..fbbb194 100755
--- a/k8s-bootstrap-container/load-blueprints.sh
+++ b/k8s-bootstrap-container/load-blueprints.sh
@@ -18,7 +18,8 @@ k8s-tca.yaml \
k8s-ves.yaml \
k8s-snmptrap.yaml \
k8s-prh.yaml \
-k8s-hv-ves.yaml
+k8s-hv-ves.yaml \
+k8s-datafile-collector.yaml
"
BPDEST=blueprints
diff --git a/k8s-bootstrap-container/pom.xml b/k8s-bootstrap-container/pom.xml
index 7b2096d..6d65969 100644
--- a/k8s-bootstrap-container/pom.xml
+++ b/k8s-bootstrap-container/pom.xml
@@ -27,7 +27,7 @@ limitations under the License.
<groupId>org.onap.dcaegen2.deployments</groupId>
<artifactId>k8s-bootstrap-container</artifactId>
<name>dcaegen2-deployments-k8s-bootstrap-container</name>
- <version>1.4.2</version>
+ <version>1.4.3</version>
<url>http://maven.apache.org</url>
<properties>
<project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
diff --git a/pnda-bootstrap-container/Dockerfile b/pnda-bootstrap-container/Dockerfile
index 6a93aa9..1b90d65 100644
--- a/pnda-bootstrap-container/Dockerfile
+++ b/pnda-bootstrap-container/Dockerfile
@@ -18,12 +18,11 @@
FROM python:2.7.15 as build
-ARG PNDARELEASE=develop
+ARG PNDACLITAG=2.0.0
+ARG PLATFORMSALTTAG=5.0.0
-# RUN git clone -b $PNDARELEASE https://github.com/pndaproject/pnda-cli.git
-# Use this repository temporary until it's merged into PNDA upstream
-RUN git clone -b existing-network https://github.com/donaldh/pnda-cli.git
-RUN git clone -b $PNDARELEASE https://github.com/pndaproject/platform-salt.git
+RUN git clone -b $PNDACLITAG https://github.com/pndaproject/pnda-cli.git
+RUN git clone -b $PLATFORMSALTTAG https://github.com/pndaproject/platform-salt.git
RUN pip2 install --no-cache-dir -r pnda-cli/cli/requirements.txt --install-option="--prefix=/install"
diff --git a/pnda-mirror-container/Dockerfile b/pnda-mirror-container/Dockerfile
index c6b8f30..3fdcfee 100644
--- a/pnda-mirror-container/Dockerfile
+++ b/pnda-mirror-container/Dockerfile
@@ -19,6 +19,9 @@
FROM centos:7.5.1804 as build
ARG PNDARELEASE=develop
+# Can be HDP or CDH
+ARG HADOOPDIST=HDP
+
RUN yum clean all && rm -rf /var/cache/yum/* && yum install gettext git -y
@@ -32,7 +35,7 @@ RUN ./install-build-tools.sh
RUN yum install bzip2 make which -y
RUN source ./set-pnda-env.sh \
- && ./build-pnda.sh BRANCH $PNDARELEASE HDP
+ && PARALLEL="--jobs 1" ./build-pnda.sh BRANCH $PNDARELEASE $HADOOPDIST
FROM nginx:alpine
diff --git a/k8s-bootstrap-container/bootstrap.sh b/k8s-bootstrap-container/bootstrap.sh
index b4a05a7..43a0537 100755
--- a/k8s-bootstrap-container/bootstrap.sh
+++ b/k8s-bootstrap-container/bootstrap.sh
@@ -217,12 +217,13 @@ PH_PID=$!
wait ${INV_PID} ${DH_PID} ${PH_PID}
# Deploy service components
# tca, ves, prh, hv-ves can be deployed simultaneously
deploy tca k8s-tca.yaml k8s-tca-inputs.yaml &
deploy ves k8s-ves.yaml k8s-ves-inputs.yaml &
deploy snmptrap k8s-snmptrap.yaml k8s-snmptrap-inputs.yaml &
deploy prh k8s-prh.yaml k8s-prh-inputs.yaml &
deploy hv-ves k8s-hv-ves.yaml k8s-hv_ves-inputs.yaml &
+deploy datafile-collector k8s-datafile-collector.yaml k8s-datafile-collector-inputs.yaml &
# holmes_rules must be deployed before holmes_engine, but holmes_rules can go in parallel with other service components
deploy holmes_rules k8s-holmes-rules.yaml k8s-holmes_rules-inputs.yaml
deploy holmes_engine k8s-holmes-engine.yaml k8s-holmes_engine-inputs.yaml
@@ -217,12 +217,13 @@ PH_PID=$!
wait ${INV_PID} ${DH_PID} ${PH_PID}
# Deploy service components
-# tca, ves, prh, hv-ves can be deployed simultaneously
+# tca, ves, prh, hv-ves, datafile-collector can be deployed simultaneously
deploy tca k8s-tca.yaml k8s-tca-inputs.yaml &
deploy ves k8s-ves.yaml k8s-ves-inputs.yaml &